@@ -30,7 +30,7 @@
 
 using namespace Gravatar;
 
-class Gravatar::GravatarResolvUrlJobPrivate
+class Q_DECL_HIDDEN Gravatar::GravatarResolvUrlJobPrivate
 {
 public:
     GravatarResolvUrlJobPrivate()
@@ -45,7 +45,6 @@ public:
 
     enum Backend {
         None = 0x0,
-        Libravatar = 0x1,
         Gravatar = 0x2
     };
     int mBackends = Gravatar;
@@ -74,9 +73,9 @@ bool GravatarResolvUrlJob::canStart() const
     }
 }
 
-QUrl GravatarResolvUrlJob::generateGravatarUrl(bool useLibravatar)
+QUrl GravatarResolvUrlJob::generateGravatarUrl()
 {
-    return createUrl(useLibravatar);
+    return createUrl();
 }
 
 bool GravatarResolvUrlJob::hasGravatar() const
@@ -95,8 +94,9 @@ void GravatarResolvUrlJob::startNetworkManager(const QUrl &url)
 
 void GravatarResolvUrlJob::start()
 {
-    if (d->mBackends == GravatarResolvUrlJobPrivate::None)
+    if (d->mBackends == GravatarResolvUrlJobPrivate::None) {
         d->mBackends = GravatarResolvUrlJobPrivate::Gravatar; // default is Gravatar if nothing else is selected
+    }
 
     d->mHasGravatar = false;
     if (canStart()) {
@@ -116,19 +116,17 @@ void GravatarResolvUrlJob::processNextBackend()
     }
 
     QUrl url;
-    if (d->mBackends & GravatarResolvUrlJobPrivate::Libravatar) {
-        d->mBackends &= ~GravatarResolvUrlJobPrivate::Libravatar;
-        url = createUrl(true);
-    } else if (d->mBackends & GravatarResolvUrlJobPrivate::Gravatar) {
+    if (d->mBackends & GravatarResolvUrlJobPrivate::Gravatar) {
         d->mBackends &= ~GravatarResolvUrlJobPrivate::Gravatar;
-        url = createUrl(false);
+        url = createUrl();
     }
 
     Q_EMIT resolvUrl(url);
-    if (!cacheLookup(d->mCalculatedHash))
+    if (!cacheLookup(d->mCalculatedHash)) {
         startNetworkManager(url);
-    else
+    } else {
         processNextBackend();
+    }
 }
 
 void GravatarResolvUrlJob::slotFinishLoadPixmap(QNetworkReply *reply)
@@ -141,10 +139,11 @@ void GravatarResolvUrlJob::slotFinishLoadPixmap(QNetworkReply *reply)
             GravatarCache::self()->saveGravatarPixmap(d->mCalculatedHash, d->mPixmap);
         }
     } else {
-        if (reply->error() == QNetworkReply::ContentNotFoundError)
+        if (reply->error() == QNetworkReply::ContentNotFoundError) {
             GravatarCache::self()->saveMissingGravatar(d->mCalculatedHash);
-        else
+        } else {
             qCDebug(GRAVATAR_LOG) << "Network error:" << reply->request().url() << reply->errorString();
+        }
     }
 
     processNextBackend();
@@ -160,40 +159,12 @@ void GravatarResolvUrlJob::setEmail(const QString &email)
     d->mEmail = email;
 }
 
-Hash GravatarResolvUrlJob::calculateHash(bool useLibravator)
+Hash GravatarResolvUrlJob::calculateHash()
 {
     const auto email = d->mEmail.toLower().toUtf8();
-    if (useLibravator)
-        return Hash(QCryptographicHash::hash(email, QCryptographicHash::Sha256), Hash::Sha256);
     return Hash(QCryptographicHash::hash(email, QCryptographicHash::Md5), Hash::Md5);
 }
 
-bool GravatarResolvUrlJob::fallbackGravatar() const
-{
-    return d->mBackends & GravatarResolvUrlJobPrivate::Gravatar;
-}
-
-void GravatarResolvUrlJob::setFallbackGravatar(bool fallbackGravatar)
-{
-    if (fallbackGravatar)
-        d->mBackends |= GravatarResolvUrlJobPrivate::Gravatar;
-    else
-        d->mBackends &= ~GravatarResolvUrlJobPrivate::Gravatar;
-}
-
-bool GravatarResolvUrlJob::useLibravatar() const
-{
-    return d->mBackends & GravatarResolvUrlJobPrivate::Libravatar;
-}
-
-void GravatarResolvUrlJob::setUseLibravatar(bool useLibravatar)
-{
-    if (useLibravatar)
-        d->mBackends |= GravatarResolvUrlJobPrivate::Libravatar;
-    else
-        d->mBackends &= ~GravatarResolvUrlJobPrivate::Libravatar;
-}
-
 bool GravatarResolvUrlJob::useDefaultPixmap() const
 {
     return d->mUseDefaultPixmap;
@@ -229,7 +200,7 @@ Hash GravatarResolvUrlJob::calculatedHash() const
     return d->mCalculatedHash;
 }
 
-QUrl GravatarResolvUrlJob::createUrl(bool useLibravatar)
+QUrl GravatarResolvUrlJob::createUrl()
 {
     QUrl url;
     d->mCalculatedHash = Hash();
@@ -245,13 +216,9 @@ QUrl GravatarResolvUrlJob::createUrl(bool useLibravatar)
         query.addQueryItem(QStringLiteral("s"), QString::number(d->mSize));
     }
     url.setScheme(QStringLiteral("https"));
-    if (useLibravatar) {
-        url.setHost(QStringLiteral("seccdn.libravatar.org"));
-    } else {
-        url.setHost(QStringLiteral("secure.gravatar.com"));
-    }
+    url.setHost(QStringLiteral("secure.gravatar.com"));
     url.setPort(443);
-    d->mCalculatedHash = calculateHash(useLibravatar);
+    d->mCalculatedHash = calculateHash();
     url.setPath(QLatin1String("/avatar/") + d->mCalculatedHash.hexString());
     url.setQuery(query);
     return url;
